@@ -84,7 +84,7 @@ fn update_buttons(buttons: &mut Vec<MouseButton>, wparam: WPARAM) {
     }
 }
 
-unsafe fn mouse_input<T: EventHandler + 'static>(
+fn mouse_input<T: EventHandler + 'static>(
     window: &Window,
     button: MouseButton,
     button_state: KeyState,
@@ -92,15 +92,38 @@ unsafe fn mouse_input<T: EventHandler + 'static>(
     lparam: LPARAM,
 ) -> LRESULT {
     call_handler(|eh: &mut T, state| {
-        let mouse_buttons = &mut state.mouse_buttons;
-        update_buttons(mouse_buttons, wparam);
+        let buttons = &mut state.mouse_buttons;
+        update_buttons(buttons, wparam);
         eh.mouse_input(
             window,
             button,
             button_state,
             MouseState {
                 position: lparam_to_point(lparam),
-                buttons: mouse_buttons,
+                buttons,
+            },
+        );
+    });
+    LRESULT(0)
+}
+
+fn mouse_wheel<T: EventHandler + 'static>(
+    window: &Window,
+    dir: Wheel,
+    wparam: WPARAM,
+    lparam: LPARAM,
+) -> LRESULT {
+    call_handler(|eh: &mut T, state| {
+        let delta = hiword(wparam.0 as _);
+        let buttons = &mut state.mouse_buttons;
+        update_buttons(buttons, wparam);
+        eh.mouse_wheel(
+            window,
+            dir,
+            delta as i32,
+            MouseState {
+                position: lparam_to_point(lparam),
+                buttons,
             },
         );
     });
@@ -249,6 +272,8 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 wparam,
                 lparam,
             ),
+            WM_MOUSEWHEEL => mouse_wheel::<T>(handle, Wheel::Vertical, wparam, lparam),
+            WM_MOUSEHWHEEL => mouse_wheel::<T>(handle, Wheel::Horizontal, wparam, lparam),
             WM_KEYDOWN => key_input::<T>(handle, KeyState::Pressed, wparam, lparam),
             WM_KEYUP => key_input::<T>(handle, KeyState::Released, wparam, lparam),
             WM_CHAR => {
@@ -487,11 +512,7 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                 let mut pt = POINT::default();
                 DragQueryPoint(hdrop, &mut pt);
                 call_handler(|eh: &mut T, _| {
-                    eh.drop_files(
-                        handle,
-                        &files_ref,
-                        PhysicalPosition::new(pt.x, pt.y),
-                    );
+                    eh.drop_files(handle, &files_ref, PhysicalPosition::new(pt.x, pt.y));
                 });
                 DragFinish(hdrop);
                 LRESULT(0)
